diff --git a/config/install/webform.webform.contact.yml b/config/install/webform.webform.contact.yml
index 948d22f8..61e693f8 100644
--- a/config/install/webform.webform.contact.yml
+++ b/config/install/webform.webform.contact.yml
@@ -239,7 +239,7 @@ handlers:
     handler_id: email_notification
     status: true
     conditions: {  }
-    weight: 1
+    weight: 2
     settings:
       states:
         - completed
diff --git a/modules/webform_templates/config/install/webform.webform.template_contact.yml b/modules/webform_templates/config/install/webform.webform.template_contact.yml
index 7d16cfe8..af9d4cfb 100644
--- a/modules/webform_templates/config/install/webform.webform.template_contact.yml
+++ b/modules/webform_templates/config/install/webform.webform.template_contact.yml
@@ -235,7 +235,7 @@ handlers:
     handler_id: email_notification
     status: true
     conditions: {  }
-    weight: 1
+    weight: 2
     settings:
       states:
         - completed
diff --git a/modules/webform_templates/config/install/webform.webform.template_feedback.yml b/modules/webform_templates/config/install/webform.webform.template_feedback.yml
index f7f61e69..bf0fe31e 100644
--- a/modules/webform_templates/config/install/webform.webform.template_feedback.yml
+++ b/modules/webform_templates/config/install/webform.webform.template_feedback.yml
@@ -240,7 +240,7 @@ handlers:
     handler_id: email_notification
     status: true
     conditions: {  }
-    weight: 1
+    weight: 2
     settings:
       states:
         - completed
diff --git a/tests/src/Functional/WebformBrowserTestBase.php b/tests/src/Functional/WebformBrowserTestBase.php
index 9651fbdd..a06c73b6 100644
--- a/tests/src/Functional/WebformBrowserTestBase.php
+++ b/tests/src/Functional/WebformBrowserTestBase.php
@@ -428,8 +428,11 @@ abstract class WebformBrowserTestBase extends BrowserTestBase {
    */
   protected function getLastEmail() {
     $sent_emails = $this->getMails();
-    $sent_email = end($sent_emails);
-    $this->debug($sent_email);
+    // Log all messages as verbose output.
+    foreach ($sent_emails as $sent_email) {
+      $this->debug($sent_email);
+    }
+    // Return the last one.
     return $sent_email;
   }
 
diff --git a/tests/src/Functional/WebformBrowserTestBaseTest.php b/tests/src/Functional/WebformBrowserTestBaseTest.php
index d1cb8c47..b95ee8cd 100644
--- a/tests/src/Functional/WebformBrowserTestBaseTest.php
+++ b/tests/src/Functional/WebformBrowserTestBaseTest.php
@@ -59,11 +59,11 @@ class WebformBrowserTestBaseTest extends WebformBrowserTestBase {
     // Check submission load not from cache.
     $webform_submission = $this->loadSubmission($sid);
     $this->assertNotNull($webform_submission);
-    $this->assertEquals($webform_submission->getWebform()->id(), 'contact');
+    $this->assertEquals('contact', $webform_submission->getWebform()->id());
 
     // Check submission email.
     $last_email = $this->getLastEmail();
-    $this->assertEquals($last_email['id'], 'webform_contact_email_notification');
+    $this->assertEquals('webform_contact_email_notification', $last_email['id']);
 
     // Check purge submission deletes the submission.
     $this->purgeSubmissions();

diff --git a/src/Tests/Handler/WebformHandlerEmailRenderingTest.php b/src/Tests/Handler/WebformHandlerEmailRenderingTest.php
index 642dd843..21fe514f 100644
--- a/src/Tests/Handler/WebformHandlerEmailRenderingTest.php
+++ b/src/Tests/Handler/WebformHandlerEmailRenderingTest.php
@@ -40,27 +40,18 @@ class WebformHandlerEmailRenderingTest extends WebformTestBase {
     $this->drupalGet('/webform/contact');
     $this->assertRaw('core/themes/bartik/css/base/elements.css');
 
-    // Post submission and send emails.
+    // Prepare submission values.
     $edit = [
       'name' => 'Dixisset',
       'email' => 'test@test.com',
       'subject' => 'Testing contact webform from [site:name]',
       'message' => 'Please ignore this email.',
     ];
+
+    // Post submission and send emails.
     $this->postSubmission($webform, $edit);
 
-    // Check submitting contact form and sending emails using the
-    // default bartik.theme.
-    $sent_emails = $this->drupalGetMails();
-    $this->assertContains('HEADER 1 (CONTACT_EMAIL_CONFIRMATION)', $sent_emails[0]['body']);
-    $this->assertContains('Please ignore this email.', $sent_emails[0]['body']);
-    $this->assertContains('address (contact_email_confirmation)', $sent_emails[0]['body']);
-    $this->assertContains('HEADER 1 (GLOBAL)', $sent_emails[1]['body']);
-    $this->assertContains('Please ignore this email.', $sent_emails[1]['body']);
-    $this->assertContains('address (global)', $sent_emails[1]['body']);
-
-    // Disable dedicated page which will cause the form to now use the
-    // seven.theme.
+    // Now disable the dedicated page, causing the form to use the seven.theme.
     // @see \Drupal\webform\Theme\WebformThemeNegotiator
     $webform->setSetting('page', FALSE);
     $webform->save();
@@ -69,20 +60,30 @@ class WebformHandlerEmailRenderingTest extends WebformTestBase {
     $this->drupalGet('/webform/contact');
     $this->assertNoRaw('core/themes/bartik/css/base/elements.css');
 
-    // Post submission and send emails.
+    // Post submission and send emails again.
     $this->postSubmission($webform, $edit);
 
-    // Check submitting contact form and sending emails using the
-    // seven.theme but the rendered the emails still use the default
+    // Now retrieve the generated emails.
+    $confirm = $notify = array();
+    list($confirm['bartik'], $notify['bartik'], $confirm['seven'], $notify['seven']) = $this->drupalGetMails();
+
+    // No matter whether we submitted the contact form under bartik.theme or
+    // seven.theme, the rendered the emails should always use the default
     // bartik.theme.
     // @see \Drupal\webform\Plugin\WebformHandler\EmailWebformHandler::getMessage
-    $sent_emails = $this->drupalGetMails();
-    $this->assertContains('HEADER 1 (CONTACT_EMAIL_CONFIRMATION)', $sent_emails[2]['body']);
-    $this->assertContains('Please ignore this email.', $sent_emails[2]['body']);
-    $this->assertContains('address (contact_email_confirmation)', $sent_emails[2]['body']);
-    $this->assertContains('HEADER 1 (GLOBAL)', $sent_emails[3]['body']);
-    $this->assertContains('Please ignore this email.', $sent_emails[3]['body']);
-    $this->assertContains('address (global)', $sent_emails[3]['body']);
+    foreach ($confirm as $email) {
+      $this->assertEqual('webform_contact_email_confirmation', $email['id']);
+      $this->assertContains('HEADER 1 (CONTACT_EMAIL_CONFIRMATION)', $email['body']);
+      $this->assertContains('Please ignore this email.', $email['body']);
+      $this->assertContains('address (contact_email_confirmation)', $email['body']);
+    }
+
+    foreach ($notify as $email) {
+      $this->assertEqual('webform_contact_email_notification', $email['id']);
+      $this->assertContains('HEADER 1 (GLOBAL)', $email['body']);
+      $this->assertContains('Please ignore this email.', $email['body']);
+      $this->assertContains('address (global)', $email['body']);
+    }
   }
 
 }